@@ -115,13 +115,14 @@ o2cv<-function(X, Y, nc, nx, ny, group=NULL, nr_folds = 5, ncores=1,
         To <- matrix(0,nrow(Xev),nx)
         
         # Predicts y_hat
+        if(nx>0){
         for (i in 1:nx) {
             #tx <- Xev %*% o2$WYosc[ , i,drop=F]
             tx <- eigenmult(Xev, o2$WYosc[ , i,drop=F])
           #  Xev <- Xev - tx %*% t(o2$PYosc[ , i,drop=F])
             Xev <- Xev - eigenmult(tx, t(o2$PYosc[ , i,drop=F]))
             To[,i]<- tx
-        }
+        }}
       #  Tpp <- Xev %*% o2$Xloading
       #  Y_hat <- Tpp %*% o2$BT %*% t(o2$Yloading)
         Tpp <- eigenmult(Xev, o2$Xloading)
@@ -130,6 +131,7 @@ o2cv<-function(X, Y, nc, nx, ny, group=NULL, nr_folds = 5, ncores=1,
         # Predicts x_hat
         Yev <- Y[cls.grp == k & is.na(cls.grp)==FALSE,]
         Uo <- matrix(0,nrow(Yev),ny)
+        if(ny>0){
         for (i in 1:ny) {
           #  ux <-  Yev %*% o2$CXosc[ , i,drop=F]
             ux <-  eigenmult(Yev, o2$CXosc[ , i,drop=F])
@@ -137,6 +139,7 @@ o2cv<-function(X, Y, nc, nx, ny, group=NULL, nr_folds = 5, ncores=1,
             Yev <- Yev - eigenmult(ux, t(o2$PXosc[ , i,drop=F]))
             Uo[,i] <- ux
         }
+        }
      #   Upp <- Yev %*% o2$Yloading
      #   X_hat <- Upp %*% o2$BU %*% t(o2$Xloading)
         Upp <- eigenmult(Yev, o2$Yloading)
